@@ -66,7 +66,7 @@ def calc_retrieval_metrics(
         for k in top_k_arg:
             if k > gallery_sz:
                 warnings.warn(
-                    f"Your desired k={k} more than gallery_size={gallery_sz}."
+                    f"Your desired k={k} more than gallery_size={gallery_sz}. "
                     f"We'll calculate metrics with k limited by the gallery size."
                 )
 
@@ -109,15 +109,15 @@ def calc_retrieval_metrics(
     return metrics
 
 
-def calc_topological_metrics(embeddings: Tensor, pfc_variance: Tuple[float, ...]) -> TMetricsDict:
+def calc_topological_metrics(embeddings: Tensor, pcf_variance: Tuple[float, ...]) -> TMetricsDict:
     """
     Function to evaluate different topological metrics.
 
     Args:
         embeddings: Embeddings matrix with the shape of ``[n_embeddings, embeddings_dim]``.
-        pfc_variance: Values in range [0, 1]. Find the number of components such that the amount
+        pcf_variance: Values in range [0, 1]. Find the number of components such that the amount
                       of variance that needs to be explained is greater than the percentage specified
-                      by ``pfc_variance``.
+                      by ``pcf_variance``.
 
     Returns:
         Metrics dictionary.
@@ -125,9 +125,9 @@ def calc_topological_metrics(embeddings: Tensor, pfc_variance: Tuple[float, ...]
     """
     metrics: TMetricsDict = dict()
 
-    if pfc_variance:
-        main_components = calc_pcf(embeddings, pfc_variance)
-        metrics["pcf"] = dict(zip(pfc_variance, main_components))
+    if pcf_variance:
+        main_components = calc_pcf(embeddings, pcf_variance)
+        metrics["pcf"] = dict(zip(pcf_variance, main_components))
 
     return metrics
 
@@ -152,15 +152,10 @@ def apply_mask_to_ignore(distances: Tensor, mask_gt: Tensor, mask_to_ignore: Ten
     return distances, mask_gt
 
 
-def calc_gt_mask(
-    labels: Union[np.ndarray, Tensor], is_query: Union[np.ndarray, Tensor], is_gallery: Union[np.ndarray, Tensor]
-) -> Tensor:
-    assert all(isinstance(vector, (np.ndarray, Tensor)) for vector in [labels, is_query, is_gallery])
+def calc_gt_mask(labels: Tensor, is_query: Tensor, is_gallery: Tensor) -> Tensor:
     assert labels.ndim == is_query.ndim == is_gallery.ndim == 1
     assert len(labels) == len(is_query) == len(is_gallery)
 
-    labels, is_query, is_gallery = map(_to_tensor, [labels, is_query, is_gallery])
-
     query_mask = is_query == 1
     gallery_mask = is_gallery == 1
     query_labels = labels[query_mask]
@@ -170,29 +165,35 @@ def calc_gt_mask(
     return gt_mask
 
 
-def calc_mask_to_ignore(is_query: Union[np.ndarray, Tensor], is_gallery: Union[np.ndarray, Tensor]) -> Tensor:
-    assert all(isinstance(vector, (np.ndarray, Tensor)) for vector in [is_query, is_gallery])
+def calc_mask_to_ignore(
+    is_query: Tensor, is_gallery: Tensor, sequence_ids: Optional[Union[Tensor, np.ndarray]] = None
+) -> Tensor:
     assert is_query.ndim == is_gallery.ndim == 1
     assert len(is_query) == len(is_gallery)
 
-    is_query, is_gallery = map(_to_tensor, [is_query, is_gallery])
+    if sequence_ids is not None:
+        assert sequence_ids.ndim == 1
+        assert len(is_gallery) == len(sequence_ids)
 
     ids_query = torch.nonzero(is_query).squeeze()
     ids_gallery = torch.nonzero(is_gallery).squeeze()
+
+    # this mask excludes duplicates of queries from the gallery if any
     mask_to_ignore = ids_query[..., None] == ids_gallery[None, ...]
 
+    if sequence_ids is not None:
+        # this mask ignores gallery samples taken from the same sequence as a given query
+        mask_to_ignore_seq = sequence_ids[is_query][..., None] == sequence_ids[is_gallery][None, ...]
+        mask_to_ignore = np.logical_or(mask_to_ignore, mask_to_ignore_seq)  # numpy casts tensor to numpy array
+        mask_to_ignore = torch.tensor(mask_to_ignore, dtype=torch.bool)
+
     return mask_to_ignore
 
 
-def calc_distance_matrix(
-    embeddings: Union[np.ndarray, Tensor], is_query: Union[np.ndarray, Tensor], is_gallery: Union[np.ndarray, Tensor]
-) -> Tensor:
-    assert all(isinstance(vector, (np.ndarray, Tensor)) for vector in [embeddings, is_query, is_gallery])
+def calc_distance_matrix(embeddings: Tensor, is_query: Tensor, is_gallery: Tensor) -> Tensor:
     assert is_query.ndim == 1 and is_gallery.ndim == 1 and embeddings.ndim == 2
     assert embeddings.shape[0] == len(is_query) == len(is_gallery)
 
-    embeddings, is_query, is_gallery = map(_to_tensor, [embeddings, is_query, is_gallery])
-
     query_mask = is_query == 1
     gallery_mask = is_gallery == 1
     query_embeddings = embeddings[query_mask]
@@ -483,16 +484,16 @@ def calc_fnmr_at_fmr(pos_dist: Tensor, neg_dist: Tensor, fmr_vals: Tuple[float,
     return fnmr_at_fmr
 
 
-def calc_pcf(embeddings: Tensor, pfc_variance: Tuple[float, ...]) -> List[Tensor]:
+def calc_pcf(embeddings: Tensor, pcf_variance: Tuple[float, ...]) -> List[Tensor]:
     """
     Function estimates the Principal Components Fraction (PCF) of embeddings using Principal Component Analysis.
     The metric is defined as a fraction of components needed to explain the required variance in data.
 
     Args:
         embeddings: Embeddings matrix with the shape of ``[n_embeddings, embeddings_dim]``.
-        pfc_variance: Values in range [0, 1]. Find the number of components such that the amount
+        pcf_variance: Values in range [0, 1]. Find the number of components such that the amount
                       of variance that needs to be explained is greater than the fraction specified
-                      by ``pfc_variance``.
+                      by ``pcf_variance``.
     Returns:
         List of linear dimensions as a fractions of the embeddings dimension.
 
@@ -526,16 +527,24 @@ def calc_pcf(embeddings: Tensor, pfc_variance: Tuple[float, ...]) -> List[Tensor
         because the number of principal axes is superior to the desired explained variance threshold).
 
         >>> embeddings = torch.eye(4, 10, dtype=torch.float)
-        >>> calc_pcf(embeddings, pfc_variance=(0.5, 1))
+        >>> calc_pcf(embeddings, pcf_variance=(0.5, 1))
         tensor([0.2000, 0.5000])
 
     """
     # The code below mirrors code from scikit-learn repository:
     # https://github.com/scikit-learn/scikit-learn/blob/f3f51f9b6/sklearn/decomposition/_pca.py#L491
-    _check_if_in_range(pfc_variance, 0, 1, "pfc_variance")
-    pca = PCA(embeddings)
-    n_components = pca.calc_principal_axes_number(pfc_variance).to(embeddings)
-    return n_components / embeddings.shape[1]
+    _check_if_in_range(pcf_variance, 0, 1, "pcf_variance")
+    try:
+        pca = PCA(embeddings)
+        n_components = pca.calc_principal_axes_number(pcf_variance).to(embeddings)
+        metric = n_components / embeddings.shape[1]
+    except Exception:
+        # Mostly we handle the following error here:
+        # >>> The algorithm failed to converge because the input matrix is ill-conditioned
+        # >>> or has too many repeated singular values
+        metric = [torch.tensor(float("nan"))] * len(pcf_variance)
+
+    return metric
 
 
 def extract_pos_neg_dists(
@@ -563,15 +572,6 @@ def extract_pos_neg_dists(
     return pos_dist, neg_dist
 
 
-def _to_tensor(array: Union[np.ndarray, Tensor]) -> Tensor:
-    if isinstance(array, Tensor):
-        return array
-    elif isinstance(array, np.ndarray):
-        return torch.from_numpy(array)
-    else:
-        raise TypeError("Wrong type")
-
-
 def _clip_max_with_warning(arr: Tuple[int, ...], max_el: int) -> Tuple[int, ...]:
     """
     Clip ``arr`` by upper bound ``max_el`` and raise warning if required.
