@@ -4,6 +4,7 @@ import torch
 from torch import Tensor
 from torch.nn import Module
 
+from oml.functional.losses import get_reduced
 from oml.interfaces.criterions import ITripletLossWithMiner
 from oml.interfaces.miners import ITripletsMiner, labels2list
 from oml.miners.cross_batch import TripletMinerWithMemory
@@ -26,6 +27,8 @@ class TripletLoss(Module):
 
     """
 
+    criterion_name = "triplet"  # for better logging
+
     def __init__(self, margin: Optional[float], reduction: str = "mean", need_logs: bool = False):
         """
 
@@ -75,14 +78,7 @@ class TripletLoss(Module):
                 "neg_dist": float(negative_dist.clone().detach().mean().item()),
             }
 
-        if self.reduction == "mean":
-            loss = loss.mean()
-        elif self.reduction == "sum":
-            loss = loss.sum()
-        elif self.reduction == "none":
-            return loss
-        else:
-            raise ValueError()
+        loss = get_reduced(loss, reduction=self.reduction)
 
         return loss
 
@@ -116,6 +112,8 @@ class TripletLossPlain(Module):
 
     """
 
+    criterion_name = "triplet"  # for better logging
+
     def __init__(self, margin: Optional[float], reduction: str = "mean", need_logs: bool = False):
         """
 
@@ -151,7 +149,10 @@ class TripletLossPlain(Module):
 
         anchor_ii, positive_ii, negative_ii = get_tri_ids_in_plain(n)
 
-        return self.criterion(features[anchor_ii], features[positive_ii], features[negative_ii])
+        loss = self.criterion(features[anchor_ii], features[positive_ii], features[negative_ii])
+        self.last_logs = self.criterion.last_logs
+
+        return loss
 
 
 class TripletLossWithMiner(ITripletLossWithMiner):
@@ -160,6 +161,8 @@ class TripletLossWithMiner(ITripletLossWithMiner):
 
     """
 
+    criterion_name = "triplet"  # for better logging
+
     def __init__(
         self,
         margin: Optional[float],
@@ -228,6 +231,7 @@ class TripletLossWithMiner(ITripletLossWithMiner):
             loss = self.tri_loss(anchor=anchor, positive=positive, negative=negative)
 
         self.last_logs.update(self.tri_loss.last_logs)
+        self.last_logs.update(getattr(self.miner, "last_logs", {}))
 
         if self.reduction == "mean":
             loss = loss.mean()
