@@ -30,9 +30,9 @@ class NHardTripletsMiner(ITripletsMinerInBatch):
     ):
         """
         Args:
-            n_positive: keep ``n_positive`` positive examples with large distances. If the value is a range, minimal
+            n_positive: keep ``n_positive`` positive samples with large distances. If the value is a range, minimal
                 value has to be less than the available amount of labels in batches
-            n_negative: keep ``n_negative`` negative examples with small distances
+            n_negative: keep ``n_negative`` negative pipelines with small distances
 
         Note:
             If both parameters are 1, the miner is equivalent to ``HardTripletsMiner``.
@@ -71,6 +71,7 @@ class NHardTripletsMiner(ITripletsMinerInBatch):
         Args:
             features: Features with the shape of ``[batch_size, feature_size]``
             labels: Labels with the size of ``batch_size``
+            *_: Anything here will be ignored
             ignore_anchor_mask: Parameter allows you to specify the ids of features that cannot be used as anchors. Can
             be useful with memory banks to create triplets in which at least one vector will have gradients.
 
@@ -126,7 +127,7 @@ class NHardTripletsMiner(ITripletsMinerInBatch):
         ids_p = []
         ids_n = []
 
-        for idx_anch in torch.arange(len(labels))[torch.logical_not(ignore_anchor_mask)]:
+        for idx_anch in torch.arange(len(labels), device=distmat.device)[torch.logical_not(ignore_anchor_mask)]:
             positives = hardest_positive[idx_anch_pos == idx_anch][self.positive_slice]
             negatives = hardest_negative[idx_anch_neg == idx_anch][self.negative_slice]
 
