@@ -6,11 +6,25 @@ from torch import nn
 TStateDict = OrderedDict[str, torch.Tensor]
 
 
+def remove_criterion_in_state_dict(state_dict: TStateDict) -> TStateDict:
+    if "criterion.weight" in state_dict:
+        del state_dict["criterion.weight"]
+    return state_dict
+
+
 def find_prefix_in_state_dict(state_dict: TStateDict, trial_key: str) -> str:
-    k0 = [k for k in state_dict.keys() if trial_key in k][0]
+    keys_starting_with_trial_key = [k for k in state_dict.keys() if trial_key in k]
+    assert keys_starting_with_trial_key, (
+        f"There are no keys starting from {trial_key}.\n" f"The existing keys are: {list(state_dict.keys())}"
+    )
+
+    k0 = keys_starting_with_trial_key[0]
     prefix = k0[: k0.index(trial_key)]
 
-    assert all(k.startswith(prefix) for k in state_dict.keys())
+    keys_not_starting_with_prefix = list(filter(lambda x: not x.startswith(prefix), state_dict.keys()))
+    assert (
+        not keys_not_starting_with_prefix
+    ), f"There are keys not starting from the found prefix {prefix}: {keys_not_starting_with_prefix}"
 
     return prefix
 
@@ -58,7 +72,7 @@ def patch_float(module: nn.Module, float_node: torch.Node) -> None:
         for node in graph.findAllNodes("aten::to"):
             inputs = list(node.inputs())
             for i in [1, 2]:  # dtype can be the second or third argument to aten::to()
-                if inputs[i].node()["value"] == 5:
+                if "[value=5]" in repr(inputs[i]):
                     inputs[i].node().copyAttributes(float_node)
 
     for child in module.children():
@@ -79,7 +93,7 @@ def patch_device(module: nn.Module, device_node: torch.Node) -> None:
 
     for g in graphs:
         for node in g.findAllNodes("prim::Constant"):
-            if "value" in node.attributeNames() and str(node["value"]).startswith("cuda"):
+            if "value" in node.attributeNames() and ('value="cuda' in repr(node)):
                 node.copyAttributes(device_node)
 
     for child in module.children():
