@@ -16,13 +16,16 @@ def get_argparser() -> ArgumentParser:
     return parser
 
 
-def download_mock_dataset(dataset_root: Union[str, Path], check_md5: bool = True) -> Tuple[pd.DataFrame, pd.DataFrame]:
+def download_mock_dataset(
+    dataset_root: Union[str, Path], check_md5: bool = True, df_name: str = "df.csv"
+) -> Tuple[pd.DataFrame, pd.DataFrame]:
     """
     Function to download mock dataset which is already prepared in the required format.
 
     Args:
         dataset_root: Path to save the dataset
         check_md5: Set ``True`` to check md5sum
+        df_name: Name of csv file for which output DataFrames will be returned
 
     Returns: Dataframes for the training and validation stages
 
@@ -31,8 +34,11 @@ def download_mock_dataset(dataset_root: Union[str, Path], check_md5: bool = True
 
     if not check_exists_and_validate_md5(dataset_root, MOCK_DATASET_MD5 if check_md5 else None):
         try:
+            print("Downloading from oml.daloroserver.com")
             download_folder_from_remote_storage(remote_folder=MOCK_DATASET_PATH.name, local_folder=str(dataset_root))
+            assert check_exists_and_validate_md5(dataset_root, MOCK_DATASET_MD5 if check_md5 else None)
         except Exception:
+            print("We could not download from oml.daloroserver.com, let's try Google Drive.")
             gdown.download_folder(url=MOCK_DATASET_URL_GDRIVE, output=str(dataset_root))
     else:
         print(f"Mock dataset has been downloaded already to {dataset_root}")
@@ -40,7 +46,7 @@ def download_mock_dataset(dataset_root: Union[str, Path], check_md5: bool = True
     if not check_exists_and_validate_md5(dataset_root, MOCK_DATASET_MD5 if check_md5 else None):
         raise Exception("Downloaded mock dataset is invalid.")
 
-    df = pd.read_csv(Path(dataset_root) / "df.csv")
+    df = pd.read_csv(Path(dataset_root) / df_name)
 
     df_train = df[df["split"] == "train"].reset_index(drop=True)
     df_val = df[df["split"] == "validation"].reset_index(drop=True)
